# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#
"""Menus of the game."""

from cocos.director import director
from cocos import menu, scene
import pyglet

from sound import sounds

class PlayMenu(menu.Menu):
    """The Play menu."""

    def __init__(self, game_manager):
        menu.Menu.__init__(self, _("Play!"))

        self.gm = game_manager
        self.select_sound = sounds.play_wrapper('tic')

        # then add the items
        self.items = [
            (menu.MenuItem(_('Classic'), self.on_classic)),
            (menu.MenuItem(_('Rush!'), self.on_rush)),
            (menu.MenuItem(_('Crazy'), self.on_crazy)),
            (menu.MenuItem(_('Back'), self.on_quit)),
        ]

        self.create_menu(self.items, menu.shake(), menu.shake_back())

    def on_quit(self):
        """Go back to the main menu."""
        self.gm.main_menu()

    def on_classic(self):
        """Classic mode."""
        sc = self.gm.play_classic()
        director.replace(sc)

    def on_rush(self):
        """Rush mode."""
        print "Not yet! (see bug #533251)"

    def on_crazy(self):
        """Crazy mode."""
        print "Not yet! (see bug #533287)"


class SafeQuitMenu(menu.Menu):
    """Ask if sure to exit the game."""

    def __init__(self):
        menu.Menu.__init__(self, "Have a game going on!")

        self.select_sound = sounds.play_wrapper('tic')

        # then add the items
        self.items = []

        self.items = [
            (menu.MenuItem(_('Keep playing!'), self.keep_playing)),
            (menu.MenuItem(_('Get me out of here'), self.really_exit)),
        ]

        self.create_menu(self.items, menu.shake(), menu.shake_back())


    def on_quit(self):
        """Handles the automatic escape, but keep playing."""
        self.keep_playing()

    def keep_playing(self):
        """Go back to the game!"""
        director.pop()

    def really_exit(self):
        """Quit the game."""
        pyglet.app.exit()


class MainMenu(menu.Menu):
    """Main menu for the game."""

    def __init__(self, game_manager, playing=False):
        menu.Menu.__init__(self, "Enjuewemela!")

        self.playing = playing
        self.gm = game_manager
        self.select_sound = sounds.play_wrapper('tic')

        # then add the items
        self.items = []

        if self.playing:
            self.items.append(
                (menu.MenuItem(_('Continue previous game'), self.on_continue)),
        )

        self.items.extend([
            (menu.MenuItem(_('Play new game!'), self.on_play)),
            (menu.MenuItem(_('Options'), self.on_options)),
            (menu.MenuItem(_('High scores'), self.on_highscores)),
            (menu.MenuItem(_('Credits'), self.on_credits)),
            (menu.MenuItem(_('Quit'), self.on_quit)),
        ])

        self.create_menu(self.items, menu.shake(), menu.shake_back())


    def on_play(self):
        """Play the game!"""
        scn = scene.Scene()
        scn.add(PlayMenu(self.gm), z=1)
        director.replace(scn)

    def on_continue(self):
        """Continue the previous game."""
        self.gm.continue_game()

    def on_options(self):
        """Check options."""
        print "Not yet! (see bug #534590)"

    def on_highscores(self):
        """Show the highscores."""
        print "Not yet! (see bug #534596)"

    def on_credits(self):
        """Who did the game."""
        print "Not yet! (see bug #534598)"

    def on_quit(self):
        """Quit the game.

        If the user is in the middle of a game, ask for confirmation.
        """
        if self.playing:
            scn = scene.Scene()
            scn.add(SafeQuitMenu(), z=1)
            director.push(scn)
        else:
            pyglet.app.exit()
