# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#
"""Gems for the game."""

from __future__ import division

import os
import cocos

import config

class _Gem(cocos.sprite.Sprite):
    """Gem wrapper around a sprite."""
    def __init__(self, filename):
        cocos.sprite.Sprite.__init__(self, filename)
        # piece name is the file name without the .png
        self.name = filename[:-4]
        self.pos_id = None

    def __str__(self):
        return self.name

class Gems(object):
    """A gem representation."""

    def __init__(self):
        # load all the gems
        jewels = os.listdir(os.path.join(config.BASEDIR, "jewels"))
        self.pngs = sorted(x for x in jewels
                           if x.endswith(".png") and not x.startswith('expl'))
        if len(self.pngs) != 7:
            raise ValueError("The gems (png files) in the 'gems' directory "
                             "must be 7! (found %d)" % len(self.pngs))

        __, max_both = self._get_gems_size()

        # calculate the resize factor
        self.resize_factor = config.PIECE_SIZE / max_both

    def _get_gems_size(self):
        """Return the gems and the max size in both axis."""
        # convert pngs into sprites
        all_gems = [cocos.sprite.Sprite(x) for x in self.pngs]

        # get the maximum height or width of all of them
        max_w = max(x.width for x in all_gems)
        max_h = max(x.height for x in all_gems)
        max_both = max(max_w, max_h)
        return all_gems, max_both

    def get_all(self, size=None):
        """Get all the gems, resized if indicated."""
        all_gems, max_both = self._get_gems_size()

        if size is not None:
            # resize the sprites accordingly
            resize_factor = size / max_both
            for gem in all_gems:
                gem.scale = resize_factor
        return all_gems

    def __getitem__(self, pos):
        sp = _Gem(self.pngs[pos])
        sp.scale = self.resize_factor
        sp.pos_id = pos
        return sp

gems = Gems()
