# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#

"""Module to load and manage all the sounds."""

import os

import pyglet

import config

# list of voices and effects, with each volume
EFFECTS = [
    ("pumba", .2),
    ("tic", .2),
]

VOICES = [
    ("game_over", 1),
    ("not_yet", 1),
    ("new_level", 1),
]

class Sounds(object):
    """Manager class for the sounds."""

    def __init__(self, locale="en"):
        self._sounds = {}

        pyglet.resource.path.append(os.path.join(config.BASEDIR,
                                                 'audio', 'effects'))
        pyglet.resource.path.append(os.path.join(config.BASEDIR,
                                                 'audio', 'voices', locale))
        pyglet.resource.reindex()

        for snd, vol in EFFECTS + VOICES:
            if snd in self._sounds:
                raise ValueError("Repeated resource in sound.py")
            resource = pyglet.resource.media(snd + '.ogg', streaming=False)
            self._sounds[snd] = (vol, resource)

    def play_wrapper(self, snd):
        """Return an object whose .play() plays this sound."""
        class PlayWrapper(object):
            """Wrapper."""
            # pylint: disable-msg=E0213
            def play(_):
                """Actually play the sound."""
                self.play(snd)
        return PlayWrapper()

    def play(self, snd):
        """Play a sound."""
        (volume, sound) = self._sounds[snd]
        # setting the volume here is a workaround for some pyglet/avbin bug
        sound.play().volume = volume

sounds = Sounds()
