import sys
import  os
sys.path.append(os.path.abspath("."))

import unittest

from logic_board import get_center

class TestHorizontal(unittest.TestCase):

    def test_empty(self):
        '''No three in a row.'''
        m = []
        self.assertRaises(ValueError, get_center, m)

    def test_simple(self):
        '''Simple match.'''
        m = [(1,2), (2,2), (3,2)]
        res = get_center(m)
        self.assertEqual(res, (2,2))

    def test_row_zero(self):
        '''With a zero in a row'''
        m = [(0,2), (1,2), (2,2)]
        res = get_center(m)
        self.assertEqual(res, (1,2))

    def test_col_zero(self):
        '''With a zero in a col'''
        m = [(1,0), (2,0), (3,0)]
        res = get_center(m)
        self.assertEqual(res, (2,0))

    def test_four(self):
        '''Four in a row.'''
        m = [(0,1), (1,1), (2,1), (3, 1)]
        res = get_center(m)
        self.assertEqual(res, (1,1))

    def test_five(self):
        '''Five in a row.'''
        m = [(1,3), (2,3), (3,3), (4,3), (5,3)]
        res = get_center(m)
        self.assertEqual(res, (3,3))


class TestVertical(unittest.TestCase):

    def test_simple(self):
        '''Simple match.'''
        m = [(6,1), (6,2), (6,3)]
        res = get_center(m)
        self.assertEqual(res, (6,2))

    def test_row_zero(self):
        '''With a zero in a row'''
        m = [(0,1), (0,2), (0,3)]
        res = get_center(m)
        self.assertEqual(res, (0,2))

    def test_col_zero(self):
        '''With a zero in a col'''
        m = [(3,0), (3,1), (3,2)]
        res = get_center(m)
        self.assertEqual(res, (3,1))

    def test_four(self):
        '''Four in a row.'''
        m = [(1,0), (1,1), (1,2), (1, 3)]
        res = get_center(m)
        self.assertEqual(res, (1,1))

    def test_five(self):
        '''Five in a row.'''
        m = [(3,0), (3,1), (3,2), (3,3), (3,4)]
        res = get_center(m)
        self.assertEqual(res, (3,2))


class TestComplex(unittest.TestCase):

    def test_L_ul(self):
        '''Upper left L.'''
        m = [(0,0), (0,1), (0,2), (1,2), (2,2)]
        res = get_center(m)
        self.assertEqual(res, (0,2))

    def test_L_lr(self):
        '''Lower right L.'''
        m = [(0,0), (1,0), (2,1), (2,2), (2,0)]
        res = get_center(m)
        self.assertEqual(res, (2,0))

    def test_L_ul_simple(self):
        '''Upper left L.'''
        m = [(0,1), (0,2), (0,3), (1,3), (2,3)]
        res = get_center(m)
        self.assertEqual(res, (0,3))

    def test_T_simple(self):
        '''Simple T.'''
        m = [(1,2), (2,0), (2,1), (2,2), (3,2)]
        res = get_center(m)
        self.assertEqual(res, (2,2))

    def test_T_plus1(self):
        '''T with extra roof 1.'''
        m = [(1,0), (1,1), (1,2), (1,3), (2,1), (3,1)]
        res = get_center(m)
        self.assertEqual(res, (1,1))

    def test_T_plus2(self):
        '''T with extra roof 2.'''
        m = [(1,1), (2,1), (3,1), (3,2), (3,3), (4,1)]
        res = get_center(m)
        self.assertEqual(res, (3,1))

    def test_super_cross(self):
        '''T with extra legs.'''
        m = [(0,2), (1,2), (2,2), (2,3), (2,4), (3,2), (4,2)]
        res = get_center(m)
        self.assertEqual(res, (2,2))


if __name__ == '__main__':
    unittest.main()

